#!/bin/bash
#
# ownCloud Univention Package
#  Script to ensure the UCS ROOT CA to be present in ownCloud's CA BUNDLE.
#
# Copyright 2015 it25 GmbH
#
# http://www.it25.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

set -e

# Add UCS ROOT CA to the CA bundle shipped since ownCloud 8.1
CA_BUNDLE=/var/www/owncloud/config/ca-bundle.crt
UCS_CA=/var/www/ucs-root-ca.crt
if [ -e "${CA_BUNDLE}" -a -e "${UCS_CA}" ] ; then
	echo -n "Checking ownCloud CA bundle ... "
	SUBJECT=`openssl x509 -in ${UCS_CA} -noout -text | grep -Eim 1 'Subject: ' | cut -f 2- -d ':' | cut -c 2-`
	if grep -qF "${SUBJECT}" ${CA_BUNDLE}; then
		echo "UCS CA already present."
	else
		echo -n "UCS CA is missing: "
		cp "${CA_BUNDLE}" "${CA_BUNDLE}.bak"
		(
			cat "${CA_BUNDLE}.bak"
			echo
			echo
			echo "UCS ROOT CA for domain '`dnsdomainname`'"
			echo "${SUBJECT}"
			echo '==================================================='
			cat "${UCS_CA}"
		) >"${CA_BUNDLE}"
		echo "CA appended."
	fi
fi

exit 0
